# Optical data

## Implemented optical constellation

The product resolution is the one given in [Data Access Portfolio (2014-2022, section 6.2)](https://spacedata.copernicus.eu/documents/20126/0/DAP+Release+phase2+V2_8.pdf/82297817-2b96-d3de-c397-776292336434?t=1633508426589). 
The Data Access Portfolio Document presents the offer of the datasets and data access services that are made available to the Copernicus Users in response to their Earth Observation data requirements.

| Constellations     | Class                                                   | Product Types             | Default Resolution                   | Use archive       |
|--------------------|---------------------------------------------------------|---------------------------|--------------------------------------|-------------------|
| Sentinel-2         | {meth}`~eoreader.products.optical.s2_product.S2Product` | L1C & L2A & L2Ap          | 10m                                  | ✅                 |
| Sentinel-2 Theia   | {meth}`~eoreader.products.S2TheiaProduct`               | L2A                       | 10m                                  | ✅                 |
| Sentinel-3 SLSTR   | {meth}`~eoreader.products.S3Product`                    | RBT                       | 300m                                 | ✅                 |
| Sentinel-3 OLCI    | {meth}`~eoreader.products.S3Product`                    | EFR                       | 500m                                 | ✅                 |
| Landsat 9 OLI-TIRS | {meth}`~eoreader.products.L9Product`                    | Level 1                   | 30m                                  | ✅                 |
| Landsat 8 OLI-TIRS | {meth}`~eoreader.products.L8Product`                    | Level 1                   | 30m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 7 ETM      | {meth}`~eoreader.products.L7Product`                    | Level 1                   | 30m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 5 TM       | {meth}`~eoreader.products.L5Product`                    | Level 1                   | 30m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 4 TM       | {meth}`~eoreader.products.L4Product`                    | Level 1                   | 30m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 5 MSS      | {meth}`~eoreader.products.L5Product`                    | Level 1                   | 60m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 4 MSS      | {meth}`~eoreader.products.L4Product`                    | Level 1                   | 60m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 3 MSS      | {meth}`~eoreader.products.L3Product`                    | Level 1                   | 60m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 2 MSS      | {meth}`~eoreader.products.L2Product`                    | Level 1                   | 60m                                  | COL1*: ❌, COL2: ✅ |
| Landsat 1 MSS      | {meth}`~eoreader.products.L1Product`                    | Level 1                   | 60m                                  | COL1*: ❌, COL2: ✅ |
| PlanetScope        | {meth}`~eoreader.products.PlaProduct`                   | L3A & L3B                 | 3m                                   | ✅                 |
| SkySat             | {meth}`~eoreader.products.SkySat`                       | (Collect Product) ortho_* | 0.5m                                 | ✅                 |
| Pleiades-Neo       | {meth}`~eoreader.products.PneoProduct`                  | ORT                       | 0.3 (PAN), 1.2m (MS)                 | ✅                 |
| Pleiades           | {meth}`~eoreader.products.PldProduct`                   | SEN, PRJ, ORT & MOS       | 0.5 (PAN), 2m (MS)                   | ✅                 |
| Vision-1           | {meth}`~eoreader.products.Vis1Product`                  | PRJ & ORTP                | 0.9 (PAN), 3.5m (MS)                 | ✅                 |
| SPOT 4             | {meth}`~eoreader.products.Spot45Product`                | L1A, M1B, L2A             | 10 (PAN), 20m (MS)                   | ✅                 |
| SPOT 5             | {meth}`~eoreader.products.Spot45Product`                | L1A, M1B, L2A             | 2.5 (SuperMode), 5.0 (PAN), 10m (MS) | ✅                 |
| SPOT 7             | {meth}`~eoreader.products.Spot7Product`                 | SEN, PRJ, ORT & MOS       | 1.5 (PAN), 6m (MS)                   | ✅                 |
| SPOT 6             | {meth}`~eoreader.products.Spot6Product`                 | SEN, PRJ, ORT & MOS       | 1.5 (PAN), 6m (MS)                   | ✅                 |
| Maxar**            | {meth}`~eoreader.products.MaxarProduct`                 | Standard & Ortho          | 0.5 (PAN), 2m (MS)                   | ✅                 |
| SuperView-1        | {meth}`~eoreader.products.Sv1Product`                   | L1B & L2A                 | 0.5 (PAN), 2m (MS)                   | ✅                 |

\* *Archived Landsat Collection-1 are not managed because of the tar.gz format, which is too slow to process. It is better to work on the extracted product. Landsat-9 Collection-1 products don't exist.*

\*\* *Maxar satellites: Worldview 2, 3, 4 and GeoEye-1 (but WorldView-1, QuickBird should work, however they don't have been tested). The resolution can vary around the one given here.*

```{warning}
Satellites products that cannot be used as archived have to be extracted before use.
```

The goal of **EOReader** is to implement every constellation that can be used in the [Copernicus Emergency Management Service](https://emergency.copernicus.eu/).
The constellations that can be used during CEMS activations are (as of 09/2021):  
![cems_constellations](https://www.esa.int/var/esa/storage/images/esa_multimedia/images/2021/09/copernicus_contributing_missions_overview/23461131-1-eng-GB/Copernicus_Contributing_Missions_overview_pillars.jpg)

## Optical bands

The following bands are available in **EOReader**, but may not be available for all constellations.

```{warning}
EOReader loads bands in UTM. VHR bands can be orthorectified but EOReader needs a DEM for that.
Be sure to position the environment variable `EOREADER_DEM_PATH` to the DEM you want.
```

### Satellite bands

```{note}
Optical bands are always loaded in reflectance, except for brilliance temperature bands that are left as is. 

However, the user can ask for bands "as is" by using the {meth}`~eoreader.keyword.TO_REFLECTANCE` keyword with the load and stack functions.
It will give the bands in the provider format (either DN, radiance or reflactance in uint16...).
See [the optical notebook](https://eoreader.readthedocs.io/en/latest/notebooks/optical.html#radiometric-processing) to see how to implement it.

These bands will be cleaned according to the user's needs. 
By default, only the pixels outside the detectors footprints are set to nodata.
Methods to clean optical bands are best described in the
[notebook](https://eoreader.readthedocs.io/en/latest/notebooks/optical_cleaning_methods.html) about the optical cleaning methods.
```

#### Band names

These bands are mainly based on Sentinel-2 bands. 
The names are the ones from Sentinel-2, even if sometimes it can be confusing (especially for `Coastal Aerosol` and `SWIR Cirrus` bands).

Some additions to the Sentinel-2 bands have been made (`YELLOW`, `PAN`...):

- {meth}`~eoreader.bands.SpectralBandNames.CA`: Coastal Aerosol
- {meth}`~eoreader.bands.SpectralBandNames.BLUE`
- {meth}`~eoreader.bands.SpectralBandNames.GREEN`
- {meth}`~eoreader.bands.SpectralBandNames.YELLOW`
- {meth}`~eoreader.bands.SpectralBandNames.RED`
- {meth}`~eoreader.bands.SpectralBandNames.VRE_1`: Vegetation Red Edge 1
- {meth}`~eoreader.bands.SpectralBandNames.VRE_2`: Vegetation Red Edge 2
- {meth}`~eoreader.bands.SpectralBandNames.VRE_3`: Vegetation Red Edge 3
- {meth}`~eoreader.bands.SpectralBandNames.NIR`: Near Infrared
- {meth}`~eoreader.bands.SpectralBandNames.NARROW_NIR`: Narrow Near Infrared (band `8A` for `Sentinel-2`, same as `NIR` for other sensors)
- {meth}`~eoreader.bands.SpectralBandNames.WV`: Water vapour
- {meth}`~eoreader.bands.SpectralBandNames.SWIR_CIRRUS`: Cirrus band
- {meth}`~eoreader.bands.SpectralBandNames.SWIR_1`: Short Wave Infrared 1
- {meth}`~eoreader.bands.SpectralBandNames.SWIR_2` Short Wave Infrared 2
- {meth}`~eoreader.bands.SpectralBandNames.PAN`: Panchromatic
- {meth}`~eoreader.bands.SpectralBandNames.TIR_1`: Thermal Infrared 1
- {meth}`~eoreader.bands.SpectralBandNames.TIR_2`: Thermal Infrared 2

```{note}
Note that bands that are not mapped can still be used (i.e. for Sentinel-3 OLCI and SLSTR). 
They will be called by their true name (i.e. `F1` or `Oa05`). However, 
the mapped band will have to be called with their mapped name, i.e. `BLUE` rather than `Oa04` for Sentinel-3 OLCI.
But the bands that are not present in the `alias` file won't be recognized.
```

#### Optical band mapping between constellations

| Bands (names)                  | Coastal aerosol  | Blue             | Green I      | Green             | Yellow          | Red              | Vegetation red edge | Vegetation red edge | Vegetation red edge | NIR              | Narrow NIR       | Water vapor     | SWIR – Cirrus | SWIR              | SWIR         | Panchromatic   | Thermal IR                    | Thermal IR                    |
|--------------------------------|------------------|------------------|--------------|-------------------|-----------------|------------------|---------------------|---------------------|---------------------|------------------|------------------|-----------------|---------------|-------------------|--------------|----------------|-------------------------------|-------------------------------|
| **Bands (alias)**              | `CA`             | `BLUE`           | `GREENI`     | `GREEN`           | `YELLOW`        | `RED`            | `VRE_1`             | `VRE_2`             | `VRE_3`             | `NIR`            | `NARROW_NIR`     | `WV`            | `SWIR_CIRRUS` | `SWIR_1`          | `SWIR_2`     | `PAN`          | `TIR_1`                       | `TIR_2`                       |
| Sentinel-2                     | **1** (60m)      | **2** (10m)      |              | **3** (10m)       |                 | **4** (10m)      | **5** (20m)         | **6** (20m)         | **7** (20m)         | **8** (10m)      | **8A** (20m)     | **9** (60m)     | **10** (60m)  | **11** (20m)      | **12** (20m) |                |                               |                               |
| Sentinel-2 Theia               | *Not available*  | **2** (10m)      |              | **3** (10m)       |                 | **4** (10m)      | **5** (20m)         | **6** (20m)         | **7** (20m)         | **8A** (10m)     | **8** (20m)      | *Not available* | **10** (60m)  | **11** (20m)      | **12** (20m) |                |                               |                               |
| Sentinel-3 OLCI*               | **3** (300m)     | **4** (300m)     | **5** (300m) | **6** (300m)      | **7** (300m)    | **8** (300m)     | **11** (300m)       | **12** (300m)       | **16** (300m)       | **17** (300m)    | **17** (300m)    | **20** (300m)   |               |                   |              |                |                               |                               |
| Sentinel-3 SLSTR*              |                  |                  |              | **1** (500m)      |                 | **2** (500m)     |                     |                     |                     | **3** (500m)     | **3** (500m)     |                 | **4** (500m)  | **5** (500m)      | **6** (500m) |                | **8** (1km)                   | **9** (1km)                   |
| Landsat OLI-TIRS (8-9)         | **1** (30m)      | **2** (30m)      |              | **3** (30m)       |                 | **4** (30m)      |                     |                     |                     | **5** (30m)      | **5** (30m)      |                 | **9** (30m)   | **6** (30m)       | **7** (30m)  | **8** (15m)    | **10** (100m)                 | **11** (100m)                 |
| Landsat ETM (7)                |                  | **1** (30m)      |              | **2** (30m)       |                 | **3** (30m)      |                     |                     |                     | **4** (30m)      | **4** (30m)      |                 |               | **5** (30m)       | **7** (30m)  | **8** (15m)    | **6** (60m)                   | **6** (60m)                   |
| Landsat TM (5-4)               |                  | **1** (30m)      |              | **2** (30m)       |                 | **3** (30m)      |                     |                     |                     | **4**(30m)       | **4** (30m)      |                 |               | **5** (30m)       | **7** (30m)  |                | **6** (120m)                  | **6** (120m)                  |
| Landsat MSS (5-4)              |                  |                  |              | **1** (60m)       |                 | **2** (60m)      | **3** (60m)         | **3** (60m)         | **3** (60m)         | **4** (60m)      | **4** (60m)      |                 |               |                   |              |                |                               |                               |
| Landsat MSS (1-3)              |                  |                  |              | **4** (60m)       |                 | **5** (60m)      | **6** (60m)         | **6** (60m)         | **6** (60m)         | **7** (60m)      | **7** (60m)      |                 |               |                   |              |                | **8** (240m)<br>*only for L3* | **8** (240m)<br>*only for L3* |
| PlanetScope (4 bands)          |                  | **1** (3m)       |              | **2** (3m)        |                 | **3** (3m)       |                     |                     |                     | **4** (3m)       | **4** (3m)       |                 |               |                   |              |                |                               |                               |
| PlanetScope (5 bands)          |                  | **1** (3m)       |              | **2** (3m)        |                 | **3** (3m)       | **4** (3m)          |                     || **5** (3m)          | **5** (3m)       |                  |                 |               |                   |              |                |                               |
| PlanetScope (8 bands)          | **1** (3m)       | **2** (3m)       | **3** (3m)   | **4** (3m)        | **5** (3m)      | **6** (3m)       | **7** (3m)          |                     |                     | **8** (3m)       | **8** (3m)       |                 |               |                   |              |                |                               |                               |
| SkySat                         |                  | **1** (0.5m)     |              | **2** (0.5m)      |                 | **3** (0.5m)     |                     |                     |                     | **4** (0.5m)     | **4** (0.5m)     |                 |               |                   |              |                |                               |                               |
| Pleiades                       |                  | **3** (0.5/2m)   |              | **2** (0.5/2m)    |                 | **1** (0.5/2m)   |                     |                     |                     | **4** (0.5/2m)   | **4** (0.5/2m)   |                 |               |                   |              | **1** (0.5m)   |                               |                               |
| Pleiades-Neo                   | **5** (0.3/1.2m) | **3** (0.3/1.2m) |              | **2** (0.3/1.2m)  |                 | **1** (0.3/1.2m) | **6** (0.3/1.2m)    | **6** (0.3/1.2m)    | **6** (0.3/1.2m)    | **4** (0.3/1.2m) | **4** (0.3/1.2m) |                 |               |                   |              | **1** (0.5m)   |                               |                               |
| SPOT-4                         |                  |                  |              | **1** (10/20m)    |                 | **2** (10/20m)   |                     |                     |                     | **3** (10/20m)   | **3** (10/20m)   |                 |               | **4** (10/20m)    |              | **1** (10m)    |                               |                               |
| SPOT-5                         |                  |                  |              | **1** (2.5/5/10m) |                 | **2** (2.5/5/10m)   |                     |                     |                     | **3** (2.5/5/10m)   | **3** (2.5/5/10m)   |                 |               | **4** (2.5/5/10m) |              | **1** (2.5/5m) |                               |                               |
| SPOT-6/7                       |                  | **3** (1.5/6m)   |              | **2** (1.5/6m)    |                 | **1** (1.5/6m)   |                     |                     |                     | **4** (1.5/6m)   | **4** (1.5/6m)   |                 |               |                   |              | **1** (0.5m)   |                               |                               |
| Vision-1                       |                  | **1** (0.9/3.5m) |              | **2** (0.9/3.5m)  |                 | **3** (0.9/3.5m) |                     |                     |                     | **4** (0.9/3.5m) | **4** (0.9/3.5m) |                 |               |                   |              | **1** (0.5m)   |                               |                               |
| WorldView-1                    |                  |                  |              |                   |                 |                  |                     |                     |                     |                  |                  |                 |               |                   |              | **1** (0.5m)   |                               |                               |
| WorldView-4, GeoEye-1, QuickBird |                  | **1** (0.5m/2m)  |              | **2** (0.5m/2m)   |                 | **3** (0.5m/2m)  |                     |                     |                     | **4** (0.5m/2m)  | **4** (0.5m/2m)  |                 |               |                   |              | **1** (0.5m)   |                               |                               |
| WorldView-2/3                  | **1** (0.5m/2m)  | **2** (0.5m/2m)  |              | **3** (0.5m/2m)   | **4** (0.5m/2m) | **5** (0.5m/2m)  | **6** (0.5m/2m)     | **6** (0.5m/2m)     | **6** (0.5m/2m)     | **7** (0.5m/2m)  | **7** (0.5m/2m)  | **8** (0.5m/2m) |               |                   |              | **1** (0.5m)   |                               |                               |
| Superview-1                    |                  | **1** (0.5m/2m)  |              | **2** (0.5m/2m)   |                 | **3** (0.5m/2m)  |                     |                     |                     | **4** (0.5m/2m)  | **4** (0.5m/2m)  |                 |               |                   |              | **1** (0.5m)   |                                  |

\* *Not all bands of these constellations are mapped in EOReader. However, they can still be used by using directly their name (i.e. `F1` or `Oa05`)*  

<div>                        <script type="text/javascript">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>
        <script src="https://cdn.plot.ly/plotly-2.4.2.min.js"></script>                <div id="9e31c62c-0a76-40bb-93be-d5653cd214b1" class="plotly-graph-div" style="height:700px; width:1100px;"></div>            <script type="text/javascript">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("9e31c62c-0a76-40bb-93be-d5653cd214b1")) {                    Plotly.newPlot(                        "9e31c62c-0a76-40bb-93be-d5653cd214b1",                        [{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | SWIR_2</b><br>Central Wavelength: 2190nm<br>Bandwidth: 180nm<br>Resolution: 20m<br>Band Number: 12","line":{"color":"rgb(79,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | SWIR_1</b><br>Central Wavelength: 1612nm<br>Bandwidth: 92nm<br>Resolution: 20m<br>Band Number: 11","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | CIRRUS</b><br>Central Wavelength: 1380nm<br>Bandwidth: 30nm<br>Resolution: 60m<br>Band Number: 10","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | WATER_VAPOUR</b><br>Central Wavelength: 944nm<br>Bandwidth: 20nm<br>Resolution: 60m<br>Band Number: 09","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | NIR</b><br>Central Wavelength: 833nm<br>Bandwidth: 106nm<br>Resolution: 10m<br>Band Number: 8A","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | NARROW_NIR</b><br>Central Wavelength: 864nm<br>Bandwidth: 21nm<br>Resolution: 20m<br>Band Number: 08","line":{"color":"rgb(177,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | VEGETATION_RED_EDGE_3</b><br>Central Wavelength: 781nm<br>Bandwidth: 20nm<br>Resolution: 20m<br>Band Number: 07","line":{"color":"rgb(196,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | VEGETATION_RED_EDGE_2</b><br>Central Wavelength: 740nm<br>Bandwidth: 15nm<br>Resolution: 20m<br>Band Number: 06","line":{"color":"rgb(216,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 704nm<br>Bandwidth: 15nm<br>Resolution: 20m<br>Band Number: 05","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | RED</b><br>Central Wavelength: 665nm<br>Bandwidth: 31nm<br>Resolution: 10m<br>Band Number: 04","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | GREEN</b><br>Central Wavelength: 560nm<br>Bandwidth: 36nm<br>Resolution: 10m<br>Band Number: 03","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | BLUE</b><br>Central Wavelength: 492nm<br>Bandwidth: 66nm<br>Resolution: 10m<br>Band Number: 02","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | COASTAL_AEROSOL</b><br>Central Wavelength: 442nm<br>Bandwidth: 21nm<br>Resolution: 60m<br>Band Number: 01","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | WATER_VAPOUR</b><br>Central Wavelength: 940nm<br>Bandwidth: 20nm<br>Resolution: 300m<br>Band Number: 20","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | NIR</b><br>Central Wavelength: 865nm<br>Bandwidth: 20nm<br>Resolution: 300m<br>Band Number: 17","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | VEGETATION_RED_EDGE_3</b><br>Central Wavelength: 778.75nm<br>Bandwidth: 15nm<br>Resolution: 300m<br>Band Number: 16","line":{"color":"rgb(196,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | VEGETATION_RED_EDGE_2</b><br>Central Wavelength: 753.75nm<br>Bandwidth: 7.5nm<br>Resolution: 300m<br>Band Number: 12","line":{"color":"rgb(216,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 708.75nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 11","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | RED</b><br>Central Wavelength: 665nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 08","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | YELLOW</b><br>Central Wavelength: 620nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 07","line":{"color":"gold","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | GREEN</b><br>Central Wavelength: 560nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 06","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | GREEN1</b><br>Central Wavelength: 505nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 05","line":{"color":"lightseagreen","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | BLUE</b><br>Central Wavelength: 490nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 04","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | COASTAL_AEROSOL</b><br>Central Wavelength: 442.5nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 03","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | SWIR_2</b><br>Central Wavelength: 2255.7nm<br>Bandwidth: 50.15nm<br>Resolution: 500m<br>Band Number: 06","line":{"color":"rgb(79,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | SWIR_1</b><br>Central Wavelength: 1613.4nm<br>Bandwidth: 60.68nm<br>Resolution: 500m<br>Band Number: 05","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | CIRRUS</b><br>Central Wavelength: 1374.8nm<br>Bandwidth: 20.8nm<br>Resolution: 500m<br>Band Number: 04","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | NIR</b><br>Central Wavelength: 868.0nm<br>Bandwidth: 20.6nm<br>Resolution: 500m<br>Band Number: 03","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | RED</b><br>Central Wavelength: 659.47nm<br>Bandwidth: 19.25nm<br>Resolution: 500m<br>Band Number: 02","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | GREEN</b><br>Central Wavelength: 554.27nm<br>Bandwidth: 19.26nm<br>Resolution: 500m<br>Band Number: 01","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | PANCHROMATIC</b><br>Central Wavelength: 590.0nm<br>Bandwidth: 180nm<br>Resolution: 15m<br>Band Number: 08","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | SWIR_2</b><br>Central Wavelength: 2200.0nm<br>Bandwidth: 180nm<br>Resolution: 30m<br>Band Number: 07","line":{"color":"rgb(79,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | SWIR_1</b><br>Central Wavelength: 1610.0nm<br>Bandwidth: 80nm<br>Resolution: 30m<br>Band Number: 06","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | CIRRUS</b><br>Central Wavelength: 1370.0nm<br>Bandwidth: 20nm<br>Resolution: 30m<br>Band Number: 09","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | NIR</b><br>Central Wavelength: 865.0nm<br>Bandwidth: 30nm<br>Resolution: 30m<br>Band Number: 05","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | RED</b><br>Central Wavelength: 655.0nm<br>Bandwidth: 30nm<br>Resolution: 30m<br>Band Number: 04","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 03","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | BLUE</b><br>Central Wavelength: 480.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 02","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLI-TIRS | COASTAL_AEROSOL</b><br>Central Wavelength: 440.0nm<br>Bandwidth: 20nm<br>Resolution: 30m<br>Band Number: 01","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | PANCHROMATIC</b><br>Central Wavelength: 710.0nm<br>Bandwidth: 380nm<br>Resolution: 15m<br>Band Number: 08","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | SWIR_2</b><br>Central Wavelength: 2220.0nm<br>Bandwidth: 260nm<br>Resolution: 30m<br>Band Number: 07","line":{"color":"rgb(79,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | SWIR_1</b><br>Central Wavelength: 1650.0nm<br>Bandwidth: 200nm<br>Resolution: 30m<br>Band Number: 05","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | NIR</b><br>Central Wavelength: 835.0nm<br>Bandwidth: 130nm<br>Resolution: 30m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 80nm<br>Resolution: 30m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 70nm<br>Resolution: 30m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | SWIR_2</b><br>Central Wavelength: 2215.0nm<br>Bandwidth: 270nm<br>Resolution: 30m<br>Band Number: 07","line":{"color":"rgb(79,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | SWIR_1</b><br>Central Wavelength: 1650.0nm<br>Bandwidth: 200nm<br>Resolution: 30m<br>Band Number: 05","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | NIR</b><br>Central Wavelength: 830.0nm<br>Bandwidth: 140nm<br>Resolution: 30m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 80nm<br>Resolution: 30m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 70nm<br>Resolution: 30m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | NIR</b><br>Central Wavelength: 950.0nm<br>Bandwidth: 300nm<br>Resolution: 60m<br>Band Number: Landsat 1/2/3: 7; Landsat 4/5: 4","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 750.0nm<br>Bandwidth: 100nm<br>Resolution: 60m<br>Band Number: Landsat 1/2/3: 6; Landsat 4/5: 3","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | RED</b><br>Central Wavelength: 650.0nm<br>Bandwidth: 100nm<br>Resolution: 60m<br>Band Number: Landsat 1/2/3: 5; Landsat 4/5: 2","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | GREEN</b><br>Central Wavelength: 550.0nm<br>Bandwidth: 100nm<br>Resolution: 60m<br>Band Number: Landsat 1/2/3: 4; Landsat 4/5: 1","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | NIR</b><br>Central Wavelength: 865.0nm<br>Bandwidth: 40nm<br>Resolution: 3m<br>Band Number: 08","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 705.0nm<br>Bandwidth: 16nm<br>Resolution: 3m<br>Band Number: 07","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | RED</b><br>Central Wavelength: 665.0nm<br>Bandwidth: 30nm<br>Resolution: 3m<br>Band Number: 06","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | YELLOW</b><br>Central Wavelength: 610.0nm<br>Bandwidth: 20nm<br>Resolution: 3m<br>Band Number: 05","line":{"color":"gold","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | GREEN</b><br>Central Wavelength: 565.0nm<br>Bandwidth: 36nm<br>Resolution: 3m<br>Band Number: 04","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | GREEN1</b><br>Central Wavelength: 531.0nm<br>Bandwidth: 36nm<br>Resolution: 3m<br>Band Number: 03","line":{"color":"lightseagreen","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 60nm<br>Resolution: 3m<br>Band Number: 02","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | COASTAL_AEROSOL</b><br>Central Wavelength: 441.5nm<br>Bandwidth: 21nm<br>Resolution: 3m<br>Band Number: 01","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SkySat | PANCHROMATIC</b><br>Central Wavelength: 675.0nm<br>Bandwidth: 450nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SkySat | NIR</b><br>Central Wavelength: 820.0nm<br>Bandwidth: 160nm<br>Resolution: 0.5m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SkySat | RED</b><br>Central Wavelength: 650.0nm<br>Bandwidth: 90nm<br>Resolution: 0.5m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SkySat | GREEN</b><br>Central Wavelength: 555.0nm<br>Bandwidth: 80nm<br>Resolution: 0.5m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SkySat | BLUE</b><br>Central Wavelength: 482.5nm<br>Bandwidth: 65nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | PANCHROMATIC</b><br>Central Wavelength: 650.0nm<br>Bandwidth: 360nm<br>Resolution: 0.5m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | NIR</b><br>Central Wavelength: 840.0nm<br>Bandwidth: 200nm<br>Resolution: 2m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | RED</b><br>Central Wavelength: 650.0nm<br>Bandwidth: 120nm<br>Resolution: 2m<br>Band Number: 01","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 120nm<br>Resolution: 2m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,9.2,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | BLUE</b><br>Central Wavelength: 495.0nm<br>Bandwidth: 70nm<br>Resolution: 2m<br>Band Number: 03","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades-Neo | PANCHROMATIC</b><br>Central Wavelength: 625.0nm<br>Bandwidth: 350nm<br>Resolution: 0.3m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades-Neo | NIR</b><br>Central Wavelength: 825.0nm<br>Bandwidth: 110nm<br>Resolution: 1.2m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades-Neo | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 725.0nm<br>Bandwidth: 50nm<br>Resolution: 1.2m<br>Band Number: 06","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades-Neo | RED</b><br>Central Wavelength: 655.0nm<br>Bandwidth: 70nm<br>Resolution: 1.2m<br>Band Number: 01","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades-Neo | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 60nm<br>Resolution: 1.2m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades-Neo | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 70nm<br>Resolution: 1.2m<br>Band Number: 03","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades-Neo | COASTAL_AEROSOL</b><br>Central Wavelength: 425.0nm<br>Bandwidth: 50nm<br>Resolution: 1.2m<br>Band Number: 05","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Vision-1 | PANCHROMATIC</b><br>Central Wavelength: 550.0nm<br>Bandwidth: 200nm<br>Resolution: 0.9m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Vision-1 | NIR</b><br>Central Wavelength: 835.0nm<br>Bandwidth: 150nm<br>Resolution: 3.5m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Vision-1 | RED</b><br>Central Wavelength: 635.0nm<br>Bandwidth: 70nm<br>Resolution: 3.5m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Vision-1 | GREEN</b><br>Central Wavelength: 550.0nm<br>Bandwidth: 80nm<br>Resolution: 3.5m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Vision-1 | BLUE</b><br>Central Wavelength: 475.0nm<br>Bandwidth: 70nm<br>Resolution: 3.5m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6/7 | PANCHROMATIC</b><br>Central Wavelength: 597.5nm<br>Bandwidth: 295nm<br>Resolution: 1.5m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6/7 | NIR</b><br>Central Wavelength: 825.0nm<br>Bandwidth: 130nm<br>Resolution: 6m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6/7 | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 70nm<br>Resolution: 3m<br>Band Number: 01","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6/7 | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 60nm<br>Resolution: 6m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6/7 | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 70nm<br>Resolution: 6m<br>Band Number: 03","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-5 | PANCHROMATIC</b><br>Central Wavelength: 590.0nm<br>Bandwidth: 200nm<br>Resolution: 5.0m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,13.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-5 | SWIR_1</b><br>Central Wavelength: 1665.0nm<br>Bandwidth: 170nm<br>Resolution: 10m<br>Band Number: 04","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-5 | NIR</b><br>Central Wavelength: 835.0nm<br>Bandwidth: 110nm<br>Resolution: 10m<br>Band Number: 01","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-5 | RED</b><br>Central Wavelength: 645.0nm<br>Bandwidth: 70nm<br>Resolution: 10m<br>Band Number: 02","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-5 | GREEN</b><br>Central Wavelength: 550.0nm<br>Bandwidth: 120nm<br>Resolution: 10.0m<br>Band Number: 03","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,13.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-4 | PANCHROMATIC</b><br>Central Wavelength: 645.0nm<br>Bandwidth: 70nm<br>Resolution: 10m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,14.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-4 | SWIR_1</b><br>Central Wavelength: 1665.0nm<br>Bandwidth: 170nm<br>Resolution: 20m<br>Band Number: 04","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-4 | NIR</b><br>Central Wavelength: 840.0nm<br>Bandwidth: 100nm<br>Resolution: 20m<br>Band Number: 01","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-4 | RED</b><br>Central Wavelength: 645.0nm<br>Bandwidth: 70nm<br>Resolution: 20m<br>Band Number: 02","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-4 | GREEN</b><br>Central Wavelength: 545.0nm<br>Bandwidth: 90nm<br>Resolution: 20.0m<br>Band Number: 03","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,14.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>QuickBird | PANCHROMATIC</b><br>Central Wavelength: 729.0nm<br>Bandwidth: 648nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,15.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>QuickBird | NIR</b><br>Central Wavelength: 816.5nm<br>Bandwidth: 203nm<br>Resolution: 2m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>QuickBird | RED</b><br>Central Wavelength: 650.0nm<br>Bandwidth: 120nm<br>Resolution: 2m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>QuickBird | GREEN</b><br>Central Wavelength: 543.0nm<br>Bandwidth: 154nm<br>Resolution: 2m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,15.2,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>QuickBird | BLUE</b><br>Central Wavelength: 487.5nm<br>Bandwidth: 115nm<br>Resolution: 2m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,15.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-1 | PANCHROMATIC</b><br>Central Wavelength: 650.0nm<br>Bandwidth: 500nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,16.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | PANCHROMATIC</b><br>Central Wavelength: 625.0nm<br>Bandwidth: 350nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | WATER_VAPOUR</b><br>Central Wavelength: 950.0nm<br>Bandwidth: 180nm<br>Resolution: 2m<br>Band Number: 08","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | NIR</b><br>Central Wavelength: 832.5nm<br>Bandwidth: 125nm<br>Resolution: 2m<br>Band Number: 07","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 725.0nm<br>Bandwidth: 40nm<br>Resolution: 2m<br>Band Number: 06","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 60nm<br>Resolution: 2m<br>Band Number: 05","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | YELLOW</b><br>Central Wavelength: 605.0nm<br>Bandwidth: 40nm<br>Resolution: 2m<br>Band Number: 04","line":{"color":"gold","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | GREEN</b><br>Central Wavelength: 545.0nm<br>Bandwidth: 70nm<br>Resolution: 2m<br>Band Number: 03","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | BLUE</b><br>Central Wavelength: 480.0nm<br>Bandwidth: 60nm<br>Resolution: 2m<br>Band Number: 02","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-2/3 | COASTAL_AEROSOL</b><br>Central Wavelength: 425.0nm<br>Bandwidth: 50nm<br>Resolution: 2m<br>Band Number: 01","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,17.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-4/GeoEye-1 | PANCHROMATIC</b><br>Central Wavelength: 625.0nm<br>Bandwidth: 350nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,18.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-4/GeoEye-1 | NIR</b><br>Central Wavelength: 850.0nm<br>Bandwidth: 140nm<br>Resolution: 2m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-4/GeoEye-1 | RED</b><br>Central Wavelength: 672.5nm<br>Bandwidth: 35nm<br>Resolution: 2m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-4/GeoEye-1 | GREEN</b><br>Central Wavelength: 545.0nm<br>Bandwidth: 70nm<br>Resolution: 2m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView-4/GeoEye-1 | BLUE</b><br>Central Wavelength: 480.0nm<br>Bandwidth: 60nm<br>Resolution: 2m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,18.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SuperView-1 | PANCHROMATIC</b><br>Central Wavelength: 675.0nm<br>Bandwidth: 450nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SuperView-1 | NIR</b><br>Central Wavelength: 830.0nm<br>Bandwidth: 120nm<br>Resolution: 2m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SuperView-1 | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 60nm<br>Resolution: 2m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SuperView-1 | GREEN</b><br>Central Wavelength: 555.0nm<br>Bandwidth: 70nm<br>Resolution: 2m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>SuperView-1 | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 70nm<br>Resolution: 2m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,352.5030525030525,355.00610500610503,357.5091575091575,360.01221001221,362.5152625152625,365.01831501831504,367.52136752136755,370.02442002442,372.5274725274725,375.03052503052504,377.53357753357756,380.03663003663,382.53968253968253,385.04273504273505,387.54578754578756,390.04884004884,392.55189255189254,395.05494505494505,397.55799755799757,400.0610500610501,402.56410256410254,405.06715506715506,407.5702075702076,410.0732600732601,412.5763125763126,415.07936507936506,417.5824175824176,420.0854700854701,422.5885225885226,425.0915750915751,427.5946275946276,430.0976800976801,432.6007326007326,435.10378510378507,437.6068376068376,440.1098901098901,442.6129426129426,445.11599511599513,447.6190476190476,450.1221001221001,452.6251526251526,455.12820512820514,457.63125763125765,460.1343101343101,462.6373626373626,465.14041514041514,467.64346764346766,470.1465201465202,472.64957264957263,475.15262515262515,477.65567765567766,480.1587301587301,482.6617826617827,485.16483516483515,487.66788766788767,490.1709401709402,492.67399267399264,495.1770451770452,497.6800976800977,500.1831501831502,502.6862026862027,505.18925518925516,507.6923076923077,510.1953601953602,512.6984126984128,515.2014652014652,517.7045177045177,520.2075702075701,522.7106227106227,525.2136752136752,527.7167277167277,530.2197802197802,532.7228327228327,535.2258852258852,537.7289377289377,540.2319902319903,542.7350427350427,545.2380952380952,547.7411477411478,550.2442002442002,552.7472527472528,555.2503052503052,557.7533577533577,560.2564102564103,562.7594627594627,565.2625152625153,567.7655677655678,570.2686202686202,572.7716727716728,575.2747252747253,577.7777777777778,580.2808302808303,582.7838827838827,585.2869352869353,587.7899877899878,590.2930402930403,592.7960927960928,595.2991452991453,597.8021978021978,600.3052503052503,602.8083028083029,605.3113553113553,607.8144078144078,610.3174603174602,612.8205128205128,615.3235653235654,617.8266178266178,620.3296703296703,622.8327228327228,625.3357753357753,627.8388278388279,630.3418803418804,632.8449328449328,635.3479853479853,637.8510378510379,640.3540903540904,642.8571428571429,645.3601953601953,647.8632478632478,650.3663003663004,652.869352869353,655.3724053724054,657.8754578754579,660.3785103785103,662.8815628815629,665.3846153846154,667.8876678876679,670.3907203907204,672.8937728937728,675.3968253968254,677.8998778998779,680.4029304029305,682.9059829059829,685.4090354090354,687.9120879120878,690.4151404151404,692.918192918193,695.4212454212454,697.9242979242979,700.4273504273503,702.9304029304029,705.4334554334555,707.936507936508,710.4395604395604,712.9426129426129,715.4456654456654,717.948717948718,720.4517704517705,722.9548229548229,725.4578754578754,727.960927960928,730.4639804639805,732.967032967033,735.4700854700855,737.9731379731379,740.4761904761905,742.979242979243,745.4822954822955,747.985347985348,750.4884004884004,752.991452991453,755.4945054945056,757.997557997558,760.5006105006105,763.003663003663,765.5067155067155,768.009768009768,770.5128205128206,773.015873015873,775.5189255189255,778.021978021978,780.5250305250305,783.0280830280831,785.5311355311355,788.034188034188,790.5372405372406,793.040293040293,795.5433455433456,798.046398046398,800.5494505494505,803.052503052503,805.5555555555555,808.0586080586081,810.5616605616606,813.064713064713,815.5677655677655,818.0708180708181,820.5738705738706,823.0769230769231,825.5799755799756,828.083028083028,830.5860805860806,833.0891330891332,835.5921855921856,838.0952380952381,840.5982905982905,843.1013431013431,845.6043956043957,848.1074481074481,850.6105006105006,853.113553113553,855.6166056166056,858.1196581196582,860.6227106227107,863.1257631257631,865.6288156288156,868.1318681318681,870.6349206349206,873.1379731379732,875.6410256410256,878.1440781440781,880.6471306471307,883.1501831501831,885.6532356532357,888.1562881562882,890.6593406593406,893.1623931623932,895.6654456654456,898.1684981684982,900.6715506715507,903.1746031746031,905.6776556776557,908.1807081807082,910.6837606837607,913.1868131868132,915.6898656898657,918.1929181929182,920.6959706959707,923.1990231990231,925.7020757020757,928.2051282051282,930.7081807081807,933.2112332112332,935.7142857142857,938.2173382173382,940.7203907203907,943.2234432234433,945.7264957264957,948.2295482295482,950.7326007326008,953.2356532356532,955.7387057387058,958.2417582417582,960.7448107448107,963.2478632478633,965.7509157509157,968.2539682539682,970.7570207570208,973.2600732600732,975.7631257631258,978.2661782661783,980.7692307692307,983.2722832722833,985.7753357753357,988.2783882783883,990.7814407814408,993.2844932844932,995.7875457875458,998.2905982905983,1000.7936507936508,1003.2967032967033,1005.7997557997558,1008.3028083028083,1010.8058608058608,1013.3089133089134,1015.8119658119658,1018.3150183150183,1020.8180708180709,1023.3211233211233,1025.8241758241757,1028.3272283272283,1030.8302808302808,1033.3333333333335,1035.836385836386,1038.3394383394384,1040.8424908424909,1043.3455433455433,1045.8485958485958,1048.3516483516482,1050.8547008547007,1053.3577533577534,1055.8608058608058,1058.3638583638585,1060.866910866911,1063.3699633699634,1065.873015873016,1068.3760683760684,1070.8791208791208,1073.3821733821733,1075.8852258852257,1078.3882783882784,1080.8913308913309,1083.3943833943833,1085.897435897436,1088.4004884004885,1090.903540903541,1093.4065934065934,1095.9096459096459,1098.4126984126983,1100.9157509157508,1103.4188034188035,1105.921855921856,1108.4249084249084,1110.927960927961,1113.4310134310135,1115.934065934066,1118.4371184371184,1120.940170940171,1123.4432234432234,1125.9462759462758,1128.4493284493283,1130.952380952381,1133.4554334554334,1135.958485958486,1138.4615384615386,1140.964590964591,1143.4676434676435,1145.970695970696,1148.4737484737484,1150.9768009768009,1153.4798534798533,1155.982905982906,1158.4859584859585,1160.9890109890111,1163.4920634920636,1165.995115995116,1168.4981684981685,1171.001221001221,1173.5042735042734,1176.007326007326,1178.5103785103784,1181.013431013431,1183.5164835164835,1186.019536019536,1188.5225885225886,1191.025641025641,1193.5286935286936,1196.031746031746,1198.5347985347985,1201.037851037851,1203.5409035409034,1206.043956043956,1208.5470085470085,1211.050061050061,1213.5531135531137,1216.0561660561661,1218.5592185592186,1221.062271062271,1223.5653235653235,1226.068376068376,1228.5714285714284,1231.0744810744811,1233.5775335775336,1236.080586080586,1238.5836385836387,1241.0866910866912,1243.5897435897436,1246.092796092796,1248.5958485958486,1251.098901098901,1253.6019536019535,1256.105006105006,1258.6080586080586,1261.111111111111,1263.6141636141638,1266.1172161172162,1268.6202686202687,1271.1233211233211,1273.6263736263736,1276.129426129426,1278.6324786324785,1281.135531135531,1283.6385836385837,1286.1416361416361,1288.6446886446886,1291.1477411477413,1293.6507936507937,1296.1538461538462,1298.6568986568986,1301.159951159951,1303.6630036630036,1306.166056166056,1308.6691086691087,1311.1721611721612,1313.6752136752136,1316.1782661782663,1318.6813186813188,1321.1843711843712,1323.6874236874237,1326.1904761904761,1328.6935286935286,1331.196581196581,1333.6996336996338,1336.2026862026862,1338.7057387057387,1341.2087912087914,1343.7118437118438,1346.2148962148963,1348.7179487179487,1351.2210012210012,1353.7240537240536,1356.227106227106,1358.7301587301586,1361.2332112332113,1363.7362637362637,1366.2393162393164,1368.7423687423689,1371.2454212454213,1373.7484737484738,1376.2515262515262,1378.7545787545787,1381.2576312576311,1383.7606837606838,1386.2637362637363,1388.7667887667887,1391.2698412698412,1393.7728937728937,1396.2759462759464,1398.7789987789988,1401.2820512820513,1403.7851037851037,1406.2881562881562,1408.7912087912089,1411.2942612942613,1413.7973137973138,1416.3003663003662,1418.8034188034187,1421.3064713064714,1423.8095238095239,1426.3125763125763,1428.8156288156288,1431.3186813186812,1433.821733821734,1436.3247863247864,1438.8278388278388,1441.3308913308913,1443.8339438339437,1446.3369963369964,1448.840048840049,1451.3431013431014,1453.8461538461538,1456.3492063492063,1458.852258852259,1461.3553113553114,1463.8583638583639,1466.3614163614163,1468.8644688644688,1471.3675213675215,1473.870573870574,1476.3736263736264,1478.8766788766789,1481.3797313797313,1483.8827838827838,1486.3858363858365,1488.888888888889,1491.3919413919414,1493.8949938949938,1496.3980463980463,1498.901098901099,1501.4041514041514,1503.907203907204,1506.4102564102564,1508.9133089133088,1511.4163614163615,1513.919413919414,1516.4224664224664,1518.9255189255189,1521.4285714285713,1523.931623931624,1526.4346764346765,1528.937728937729,1531.4407814407814,1533.9438339438339,1536.4468864468865,1538.949938949939,1541.4529914529915,1543.956043956044,1546.4590964590964,1548.962148962149,1551.4652014652015,1553.968253968254,1556.4713064713064,1558.974358974359,1561.4774114774116,1563.980463980464,1566.4835164835165,1568.986568986569,1571.4896214896214,1573.992673992674,1576.4957264957266,1578.998778998779,1581.5018315018315,1584.004884004884,1586.5079365079364,1589.010989010989,1591.5140415140415,1594.017094017094,1596.5201465201465,1599.023199023199,1601.5262515262516,1604.029304029304,1606.5323565323565,1609.035409035409,1611.5384615384614,1614.0415140415141,1616.5445665445666,1619.047619047619,1621.5506715506715,1624.053724053724,1626.5567765567766,1629.059829059829,1631.5628815628816,1634.065934065934,1636.5689865689865,1639.0720390720392,1641.5750915750916,1644.078144078144,1646.5811965811965,1649.084249084249,1651.5873015873017,1654.0903540903541,1656.5934065934066,1659.096459096459,1661.5995115995115,1664.1025641025642,1666.6056166056167,1669.1086691086691,1671.6117216117216,1674.114774114774,1676.6178266178267,1679.1208791208792,1681.6239316239316,1684.126984126984,1686.6300366300366,1689.133089133089,1691.6361416361417,1694.1391941391942,1696.6422466422466,1699.145299145299,1701.6483516483515,1704.1514041514042,1706.6544566544567,1709.1575091575091,1711.6605616605616,1714.163614163614,1716.6666666666667,1719.1697191697192,1721.6727716727717,1724.1758241758241,1726.6788766788766,1729.1819291819293,1731.6849816849817,1734.1880341880342,1736.6910866910866,1739.194139194139,1741.6971916971918,1744.2002442002442,1746.7032967032967,1749.2063492063492,1751.7094017094016,1754.2124542124543,1756.7155067155068,1759.2185592185592,1761.7216117216117,1764.2246642246641,1766.7277167277168,1769.2307692307693,1771.7338217338217,1774.2368742368742,1776.7399267399267,1779.2429792429793,1781.7460317460318,1784.2490842490843,1786.7521367521367,1789.2551892551892,1791.7582417582416,1794.2612942612943,1796.7643467643468,1799.2673992673992,1801.7704517704517,1804.2735042735042,1806.7765567765568,1809.2796092796093,1811.7826617826618,1814.2857142857142,1816.7887667887667,1819.2918192918194,1821.7948717948718,1824.2979242979243,1826.8009768009767,1829.3040293040292,1831.8070818070819,1834.3101343101343,1836.8131868131868,1839.3162393162393,1841.8192918192917,1844.3223443223444,1846.8253968253969,1849.3284493284493,1851.8315018315018,1854.3345543345542,1856.837606837607,1859.3406593406594,1861.8437118437118,1864.3467643467643,1866.8498168498168,1869.3528693528694,1871.855921855922,1874.3589743589744,1876.8620268620268,1879.3650793650793,1881.868131868132,1884.3711843711844,1886.8742368742369,1889.3772893772893,1891.8803418803418,1894.3833943833945,1896.886446886447,1899.3894993894994,1901.8925518925519,1904.3956043956043,1906.8986568986568,1909.4017094017095,1911.904761904762,1914.4078144078144,1916.9108669108668,1919.4139194139193,1921.916971916972,1924.4200244200244,1926.923076923077,1929.4261294261294,1931.9291819291818,1934.4322344322345,1936.935286935287,1939.4383394383394,1941.9413919413919,1944.4444444444443,1946.947496947497,1949.4505494505495,1951.953601953602,1954.4566544566544,1956.9597069597069,1959.4627594627595,1961.965811965812,1964.4688644688645,1966.971916971917,1969.4749694749694,1971.978021978022,1974.4810744810745,1976.984126984127,1979.4871794871794,1981.990231990232,1984.4932844932846,1986.996336996337,1989.4993894993895,1992.002442002442,1994.5054945054944,1997.008547008547,1999.5115995115996,2002.014652014652,2004.5177045177045,2007.020757020757,2009.5238095238094,2012.026862026862,2014.5299145299145,2017.032967032967,2019.5360195360195,2022.039072039072,2024.5421245421246,2027.045177045177,2029.5482295482295,2032.051282051282,2034.5543345543344,2037.0573870573871,2039.5604395604396,2042.063492063492,2044.5665445665445,2047.069597069597,2049.5726495726494,2052.075702075702,2054.5787545787543,2057.081807081807,2059.5848595848593,2062.087912087912,2064.5909645909646,2067.094017094017,2069.5970695970695,2072.100122100122,2074.603174603175,2077.1062271062274,2079.60927960928,2082.1123321123323,2084.6153846153848,2087.118437118437,2089.6214896214897,2092.124542124542,2094.6275946275946,2097.130647130647,2099.6336996336995,2102.136752136752,2104.6398046398044,2107.142857142857,2109.6459096459093,2112.1489621489623,2114.6520146520147,2117.155067155067,2119.6581196581196,2122.161172161172,2124.6642246642245,2127.1672771672775,2129.67032967033,2132.1733821733824,2134.676434676435,2137.1794871794873,2139.6825396825398,2142.185592185592,2144.6886446886447,2147.191697191697,2149.6947496947496,2152.197802197802,2154.7008547008545,2157.203907203907,2159.7069597069594,2162.210012210012,2164.713064713065,2167.2161172161173,2169.7191697191697,2172.222222222222,2174.7252747252746,2177.2283272283275,2179.73137973138,2182.2344322344325,2184.737484737485,2187.2405372405374,2189.74358974359,2192.2466422466423,2194.7496947496948,2197.252747252747,2199.7557997557997,2202.258852258852,2204.7619047619046,2207.264957264957,2209.7680097680095,2212.271062271062,2214.774114774115,2217.2771672771673,2219.78021978022,2222.2832722832723,2224.7863247863247,2227.289377289377,2229.79242979243,2232.2954822954825,2234.798534798535,2237.3015873015875,2239.80463980464,2242.3076923076924,2244.810744810745,2247.3137973137973,2249.8168498168498,2252.319902319902,2254.8229548229547,2257.326007326007,2259.8290598290596,2262.332112332112,2264.8351648351645,2267.3382173382174,2269.84126984127,2272.3443223443223,2274.847374847375,2277.3504273504273,2279.85347985348,2282.3565323565326,2284.859584859585,2287.3626373626375,2289.86568986569,2292.3687423687425,2294.871794871795,2297.3748473748474,2299.8778998779,2302.3809523809523,2304.8840048840048,2307.387057387057,2309.8901098901097,2312.393162393162,2314.8962148962146,2317.3992673992675,2319.90231990232,2322.4053724053724,2324.908424908425,2327.4114774114773,2329.91452991453,2332.4175824175827,2334.920634920635,2337.4236874236876,2339.92673992674,2342.4297924297925,2344.932844932845,2347.4358974358975,2349.93894993895,2352.4420024420024,2354.945054945055,2357.4481074481073,2359.9511599511598,2362.454212454212,2364.9572649572647,2367.460317460317,2369.96336996337,2372.4664224664225,2374.969474969475,2377.4725274725274,2379.97557997558,2382.478632478633,2384.9816849816852,2387.4847374847377,2389.98778998779,2392.4908424908426,2394.993894993895,2397.4969474969475,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,19.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]}],                        {"annotations":[{"showarrow":false,"text":"Sentinel-2 MSI","x":200,"y":0},{"showarrow":false,"text":"Sentinel-3 OLCI","x":200,"y":1},{"showarrow":false,"text":"Sentinel-3 SLSTR","x":200,"y":2},{"showarrow":false,"text":"Landsat OLI-TIRS","x":200,"y":3},{"showarrow":false,"text":"Landsat ETM+","x":200,"y":4},{"showarrow":false,"text":"Landsat TM","x":200,"y":5},{"showarrow":false,"text":"Landsat MSS","x":200,"y":6},{"showarrow":false,"text":"PlanetScope","x":200,"y":7},{"showarrow":false,"text":"SkySat","x":200,"y":8},{"showarrow":false,"text":"Pleiades","x":200,"y":9},{"showarrow":false,"text":"Pleiades-Neo","x":200,"y":10},{"showarrow":false,"text":"Vision-1","x":200,"y":11},{"showarrow":false,"text":"Spot-6/7","x":200,"y":12},{"showarrow":false,"text":"Spot-5","x":200,"y":13},{"showarrow":false,"text":"Spot-4","x":200,"y":14},{"showarrow":false,"text":"QuickBird","x":200,"y":15},{"showarrow":false,"text":"WorldView-1","x":200,"y":16},{"showarrow":false,"text":"WorldView-2/3","x":200,"y":17},{"showarrow":false,"text":"WorldView-4/GeoEye-1","x":200,"y":18},{"showarrow":false,"text":"SuperView-1","x":200,"y":19},{"align":"left","font":{"size":10},"showarrow":false,"text":"<i>Only the bands mapped in EOReader are displayed. Thermal bands are discarded.<br>The band number can be different in some products (especially for VHR data).</i>","x":0,"xref":"paper","y":-0.075,"yref":"paper"}],"autosize":false,"height":700,"images":[{"sizex":0.09,"sizey":0.09,"source":"https://raw.githubusercontent.com/sertit/eoreader/master/docs/_static/eoreader.png","x":1,"xanchor":"right","xref":"paper","y":1.005,"yanchor":"bottom","yref":"paper"},{"sizex":0.09,"sizey":0.09,"source":"https://raw.githubusercontent.com/sertit/eoreader/master/docs/_static/logo-sertit.png","x":0.92,"xanchor":"right","xref":"paper","y":1.005,"yanchor":"bottom","yref":"paper"}],"legend":{"title":{"text":"Band Names"}},"margin":{"b":0,"l":0,"pad":0,"r":0,"t":70},"plot_bgcolor":"aliceblue","template":{"data":{"bar":[{"error_x":{"color":"#2a3f5f"},"error_y":{"color":"#2a3f5f"},"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"bar"}],"barpolar":[{"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"barpolar"}],"carpet":[{"aaxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"baxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"type":"carpet"}],"choropleth":[{"colorbar":{"outlinewidth":0,"ticks":""},"type":"choropleth"}],"contour":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"contour"}],"contourcarpet":[{"colorbar":{"outlinewidth":0,"ticks":""},"type":"contourcarpet"}],"heatmap":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"heatmap"}],"heatmapgl":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"heatmapgl"}],"histogram":[{"marker":{"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"histogram"}],"histogram2d":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"histogram2d"}],"histogram2dcontour":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"histogram2dcontour"}],"mesh3d":[{"colorbar":{"outlinewidth":0,"ticks":""},"type":"mesh3d"}],"parcoords":[{"line":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"parcoords"}],"pie":[{"automargin":true,"type":"pie"}],"scatter":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatter"}],"scatter3d":[{"line":{"colorbar":{"outlinewidth":0,"ticks":""}},"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatter3d"}],"scattercarpet":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattercarpet"}],"scattergeo":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattergeo"}],"scattergl":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattergl"}],"scattermapbox":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattermapbox"}],"scatterpolar":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatterpolar"}],"scatterpolargl":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatterpolargl"}],"scatterternary":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatterternary"}],"surface":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"surface"}],"table":[{"cells":{"fill":{"color":"#EBF0F8"},"line":{"color":"white"}},"header":{"fill":{"color":"#C8D4E3"},"line":{"color":"white"}},"type":"table"}]},"layout":{"annotationdefaults":{"arrowcolor":"#2a3f5f","arrowhead":0,"arrowwidth":1},"autotypenumbers":"strict","coloraxis":{"colorbar":{"outlinewidth":0,"ticks":""}},"colorscale":{"diverging":[[0,"#8e0152"],[0.1,"#c51b7d"],[0.2,"#de77ae"],[0.3,"#f1b6da"],[0.4,"#fde0ef"],[0.5,"#f7f7f7"],[0.6,"#e6f5d0"],[0.7,"#b8e186"],[0.8,"#7fbc41"],[0.9,"#4d9221"],[1,"#276419"]],"sequential":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"sequentialminus":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]},"colorway":["#636efa","#EF553B","#00cc96","#ab63fa","#FFA15A","#19d3f3","#FF6692","#B6E880","#FF97FF","#FECB52"],"font":{"color":"#2a3f5f"},"geo":{"bgcolor":"white","lakecolor":"white","landcolor":"#E5ECF6","showlakes":true,"showland":true,"subunitcolor":"white"},"hoverlabel":{"align":"left"},"hovermode":"closest","mapbox":{"style":"light"},"paper_bgcolor":"white","plot_bgcolor":"#E5ECF6","polar":{"angularaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"bgcolor":"#E5ECF6","radialaxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"scene":{"xaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","gridwidth":2,"linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white"},"yaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","gridwidth":2,"linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white"},"zaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","gridwidth":2,"linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white"}},"shapedefaults":{"line":{"color":"#2a3f5f"}},"ternary":{"aaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"baxis":{"gridcolor":"white","linecolor":"white","ticks":""},"bgcolor":"#E5ECF6","caxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"title":{"x":0.05},"xaxis":{"automargin":true,"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","zerolinewidth":2},"yaxis":{"automargin":true,"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","zerolinewidth":2}}},"title":{"font":{"size":20},"text":"<b><a href='https://eoreader.readthedocs.io/en/latest/'>EOReader</a> Spectral Band Mapping</b>"},"width":1100,"xaxis":{"showgrid":false,"tickvals":[300,400,500,600,700,800,900,1000,1100,1200,1300,1400,1500,1600,1700,1800,1900,2000,2100,2200,2300],"title":{"text":"Wavelength (nm)"}},"yaxis":{"showticklabels":false,"tickvals":[-0.5,0.5,1.5,2.5,3.5,4.5,5.5,6.5,7.5,8.5,9.5,10.5,11.5,12.5,13.5,14.5,15.5,16.5,17.5,18.5,19.5],"title":{"text":"Constellations"},"zeroline":false}},                        {"responsive": true}                    )                };                            </script>        </div>

[Click here](https://eoreader.readthedocs.io/en/latest/_static/optical_band_mapping.html) to see the graph in a larger format.


### Cloud bands

Maximum 5 cloud bands are available, according to the files provided in the data. All the bands are rasterized and
orthorectified if needed (for Sentinel-2 or 3 data for example), ready to be stacked.

The only difference with the other bands is that the cloud bands are provided in `uint8` and have a nodata equal to 255.

- {meth}`~eoreader.bands.CloudsBandNames.RAW_CLOUDS`: Raw Cloud file as provided (the only changes are the
  orthorectification and rasterization). Can provide other flags, or cloud probability.
- {meth}`~eoreader.bands.CloudsBandNames.CLOUDS`: Cloud presence (1) or absence (0). If clouds are provided in
  probabilities, their presence is determined according to Landsat definition (proba> 67%)
- {meth}`~eoreader.bands.CloudsBandNames.CIRRUS`: Cirrus presence (1) or absence (0). If clouds are provided in
  probabilities, their presence is determined according to Landsat definition (proba> 67%)
- {meth}`~eoreader.bands.CloudsBandNames.SHADOWS`: Shadows presence (1) or absence (0). If clouds are provided in
  probabilities, their presence is determined according to Landsat definition (proba> 67%)
- {meth}`~eoreader.bands.CloudsBandNames.ALL_CLOUDS`: Cloud **OR** Cirrus **OR** Shadows presence (1) or absence (0).  
  Do not take into account missing bands (i.e. for Landsat MSS constellation, `ALL_CLOUDS` == `CLOUDS`)

| Sensors                      | Cloud files | Clouds Bands                                              |
|------------------------------|-------------|-----------------------------------------------------------|
| Sentinel-2                   | ✅           | `RAW_CLOUDS`, `CLOUDS`, `CIRRUS`, `ALL_CLOUDS`            |
| Sentinel-2 Theia             | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS` |
| Sentinel-3 OLCI              | ❌           |                                                           |
| Sentinel-3 SLSTR             | ✅           | `RAW_CLOUDS`, `CLOUDS`, `CIRRUS`, `ALL_CLOUDS`            |
| Landsat 9                    | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS` |
| Landsat 8                    | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS` |
| Landsat 7                    | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `ALL_CLOUDS`           |
| Landsat 5 TM                 | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `ALL_CLOUDS`           |
| Landsat 4 TM                 | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `ALL_CLOUDS`           |
| Landsat 5 MSS                | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| Landsat 4 MSS                | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| Landsat 3                    | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| Landsat 2                    | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| Landsat 1                    | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| PlanetScope                  | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS` |
| SkySat                       | ✅           | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS` |
| Pleiades                     | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| Pleiades-Neo                 | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| SPOT-4/5                     | ❌           |                                                           |
| SPOT-6/7                     | ✅           | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`                      |
| Vision-1                     | ❌           |                                                           |
| Maxar (GeoEye-1, WorldViews) | ❌           |                                                           |
| SuperView-1                  | ❌           |                                                           |

### DEM bands

Optical constellations can all load {meth}`~eoreader.bands.DemBandNames.DEM`, {meth}`~eoreader.bands.DemBandNames.SLOPE`
and {meth}`~eoreader.bands.DemBandNames.HILLSHADE` bands. 
The `SLOPE` band is given in degrees. 
Please post an issue if you need this band in `percent`.

Use the environment variable `EOREADER_DEM_PATH` to position your worldwide DEM. You can
use both a local path e.g. `/mnt/dataserver/dems/srtm_30_v4/index.vrt` or `\\dataserver\DEMS\srtm_30_v4\index.vrt` or
a URL pointing to a web resources hosted on a S3 compatible storage e.g. 
`https://s3.storage.com/dem-bucket/srtm_cog.tif` (not available on Windows for now).

### Available spectral indices

| Spectral Indices                         | Needed bands                                      | Accepted constellations                                                                                       |
|------------------------------------------|---------------------------------------------------|---------------------------------------------------------------------------------------------------------------|
| {meth}`~eoreader.bands.indices.AFRI_1_6` | `NIR`, `SWIR_1`                                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM, SPOT-4/5                                                   |
| {meth}`~eoreader.bands.indices.AFRI_2_1` | `NIR`, `SWIR_2`                                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.AWEInsh`  | `BLUE`, `GREEN`, `NIR`, `SWIR_1`, `SWIR_2`        | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.AWEIsh`   | `GREEN`, `NIR`, `SWIR_1`, `SWIR_2`                | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.BAI`      | `RED`, `NIR`                                      | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.BAIS2`    | `RED`, `NIR`, `VRE_1`, `VRE_2`, `VRE_3`, `SWIR_2` | Sentinel-2                                                                                                    |
| {meth}`~eoreader.bands.indices.BSI`      | `BLUE`, `RED`, `NIR`, `SWIR_1`                    | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.CIG`      | `GREEN`, `NIR`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.DSWI`     | `GREEN`, `RED`, `NIR`, `SWIR_1`                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.VARI`     | `NIR`, `RED`, `BLUE`                              | All optical constellations except for Landsat MSS, SPOT-4/5 and Sentinel-3 SLSTR                              |
| {meth}`~eoreader.bands.indices.GLI`      | `GREEN`, `RED`, `BLUE`                            | All optical constellations except for Landsat MSS, SPOT-4/5 and Sentinel-3 SLSTR                              |
| {meth}`~eoreader.bands.indices.EVI`      | `NIR`, `RED`, `BLUE`                              | All optical constellations except for Landsat MSS, SPOT-4/5 and Sentinel-3 SLSTR                              |
| {meth}`~eoreader.bands.indices.GNDVI`    | `GREEN`, `NIR`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.GVMI`     | `NIR`, `SWIR_2`                                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.GRI`      | `GREEN`, `RED`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.MNDWI`    | `GREEN`, `SWIR_1`                                 | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM, SPOT-4/5                                                   |
| {meth}`~eoreader.bands.indices.NBR`      | `NIR`, `SWIR_2`                                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.NDGRI`    | `GREEN`, `RED`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.NDMI`     | `NIR`, `SWIR_1`                                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM, SPOT-4/5                                                             |
| {meth}`~eoreader.bands.indices.NDMI21`   | `NIR`, `SWIR_2`                                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.NDRE2`    | `NIR`, `VRE_1`                                    | Sentinel-2, Sentinel-3 OLCI, Landsat MSS                                                                      |
| {meth}`~eoreader.bands.indices.NDRE3`    | `NIR`, `VRE_2`                                    | Sentinel-2, Sentinel-3 OLCI, Landsat MSS                                                                      |
| {meth}`~eoreader.bands.indices.CI1`      | `VRE_3`, `VRE_2`                                  | Sentinel-2, Sentinel-3 OLCI                                                                                   |
| {meth}`~eoreader.bands.indices.CI2`      | `VRE_2`, `VRE_1`                                  | Sentinel-2, Sentinel-3 OLCI                                                                                   |
| {meth}`~eoreader.bands.indices.NDVI`     | `RED`, `NIR`                                      | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.NDWI`     | `GREEN`, `NIR`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.OSAVI`    | `RED`, `NIR`                                      | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.PANI`     | `RED`, `GREEN`, `BLUE`                            | All optical constellations except for Landsat MSS, SPOT-4/5 and Sentinel-3 SLSTR                              |
| {meth}`~eoreader.bands.indices.RDI`      | `NIR`, `SWIR_2`                                   | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.RGI`      | `GREEN`, `RED`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.RI`       | `GREEN`, `VRE_1`                                  | Sentinel-2, Sentinel-3 OLCI, Landsat MSS, PlanetScope (5 bands), WorldView-2/3 (8 bands), Pleiades-Neo (full) |
| {meth}`~eoreader.bands.indices.SBI`      | `RED`, `NIR`                                      | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.SAVI`     | `RED`, `NIR`                                      | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.SCI`      | `RED`, `GREEN`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.SI`       | `GREEN`, `RED`                                    | All optical constellations                                                                                    |
| {meth}`~eoreader.bands.indices.SRSWIR`   | `SWIR_1`, `SWIR_2`                                | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.TCBRI`    | `BLUE`, `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.TCGRE`    | `BLUE`, `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.TCWET`    | `BLUE`, `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.VARI`     | `GREEN`, `RED`, `BLUE`                            | All optical constellations except for Landsat MSS, SPOT-4/5 and Sentinel-3 SLSTR                              |
| {meth}`~eoreader.bands.indices.WI`       | `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2`         | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM                                                             |
| {meth}`~eoreader.bands.indices.WV_BI`    | `VRE_1`, `CA`                                     | Sentinel-2, Sentinel-3 OLCI, Landsat OLCI, WorldView-2/3 (8 bands), Pleiades-Neo (full)                       |
| {meth}`~eoreader.bands.indices.WV_SI`    | `YELLOW`, `GREEN`                                 | Sentinel-3 OLCI, WorldView-2/3 (8 bands)                                                                      |
| {meth}`~eoreader.bands.indices.WV_VI`    | `WV`, `RED`                                       | Sentinel-2, Sentinel-3 OLCI, WorldView-2/3 (8 bands)                                                          |
| {meth}`~eoreader.bands.indices.WV_WI`    | `WV`, `CA`                                        | Sentinel-2, Sentinel-3 OLCI, WorldView-2/3 (8 bands)                                                          |

```{note}
WorldView-1 is not concerned by spectral indices as it only has a panchromatic band
```


## Documentary Sources

- [Data Access Portfolio (2014-2022, section 6.2)](https://spacedata.copernicus.eu/documents/20126/0/DAP+Release+phase2+V2_8.pdf/82297817-2b96-d3de-c397-776292336434?t=1633508426589)

### Copernicus

- [Copernicus Contributing Missions](https://www.esa.int/ESA_Multimedia/Images/2021/09/Copernicus_Contributing_Missions_overview)

### Landsat

- [Collection 1 vs Collection 2](https://www.usgs.gov/media/files/landsat-collection-1-vs-collection-2-summary)
- [Quality assessment Collection 1](https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-1-level-1-quality-assessment-band)
- [Quality assessment Collection 2](https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-2-quality-assessment-bands)
- [MSS Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-1-5-mss-collection-2-level-1-data-format-control-book)
- [TM Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-4-5-tm-collection-2-level-1-data-format-control-book)
- [ETM Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-7-etm-collection-2-level-1-data-format-control-book)
- [OLCI Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-8-level-1-data-format-control-book)

### Sentinel-2

- [Cloud masks](https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-2-msi/level-1c/cloud-masks)
- [Product Specification (Processing Baseline < 4.0)](https://sentinel.esa.int/documents/247904/349490/S2_MSI_Product_Specification.pdf)
- [Product Specification (Processing Baseline > 4.0)](https://sentinels.copernicus.eu/documents/247904/685211/Sentinel-2-Products-Specification-Document-14_8.pdf)

### Sentinel-2 Theia

- [Product Format](https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/)

### Sentinel-3

- [OLCI main page](https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-olci)
- [SLSTR main page](https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-slstr)
- [OLCI Handbook](https://sentinel.esa.int/documents/247904/4598069/Sentinel-3-OLCI-Land-Handbook.pdf/455f8c88-520f-da18-d744-f5cda41d2d91)
- [SLSTR Handbook](https://sentinel.esa.int/documents/247904/4598085/Sentinel-3-SLSTR-Land-Handbook.pdf/bee342eb-40d4-9b31-babb-8bea2748264a)
- [OLCI Product Format](https://sentinel.esa.int/documents/247904/1872756/Sentinel-3-OLCI-Product-Data-Format-Specification-OLCI-Level-1)
- [SLSTR Product Format](https://sentinel.esa.int/documents/247904/0/Sentinel-3_Product_Format_Specification_Product_Structures/27300baa-b594-4a56-9efc-5538c71899d1)
- [SLSTR Clouds](https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-slstr/level-1/cloud-identification)

### PlanetScope and SkySat

- [Product Specification](https://assets.planet.com/docs/Planet_Combined_Imagery_Product_Specs_letter_screen.pdf)
- [Instruments](https://developers.planet.com/docs/apis/data/sensors/)
- [Usable Data Mask](https://developers.planet.com/docs/data/udm-2/)
- [On Medium](https://medium.com/geoplexing/getting-started-with-planet-imagery-part-3-items-and-ordering-476a1a21618c)

### Vision-1

- [Vision-1 on Airbus Website](https://www.intelligence-airbusds.com/imagery/constellation/vision1)
- [Presentation of the satellite](https://www.intelligence-airbusds.com/automne/api/docs/v1.0/document/download/ZG9jdXRoZXF1ZS1kb2N1bWVudC02MDIyNg==/ZG9jdXRoZXF1ZS1maWxlLTYwMjI1/Vision-1_web_201906.pdf)
- [User guide](https://www.intelligence-airbusds.com/automne/api/docs/v1.0/document/download/ZG9jdXRoZXF1ZS1kb2N1bWVudC02ODMwNQ==/ZG9jdXRoZXF1ZS1maWxlLTY4MzAy/vision-1-imagery-user-guide-20210217)

### DIMAP V1: SPOT-4/5
- [Product Format (a bit too old)](http://www.engesat.com.br/wp-content/uploads/S5-ST-73-1-CN_2_9-Spec-Format-Produits-SPOT.pdf)
- [Preprocessing levels](https://earth.esa.int/eogateway/documents/20142/37627/SPOTScene-SPOTView-preprocessing-levels.pdf)
- [Reolution and spectral modes](https://www.intelligence-airbusds.com/en/8799-resolution-and-spectral-bands)
- [Convert to reflectance](https://spot.cnes.fr/sites/default/files/migration/smsc/spot/calibration_synthesis_SPOT1245_ed1.pdf)

### DIMAP V2: Pleiades, SPOT-6/7

- [DIMAP V2 Format](https://www.intelligence-airbusds.com/en/8723-pleiades-and-spot-6-7-format-delivery)
- [Pleiades User Guide (2019)](https://engesat.com.br/wp-content/uploads/PleiadesUserGuide-17062019.pdf)
- [SPOT-6/7 User Guide (2019)](https://earth.esa.int/eogateway/documents/20142/37627/SPOT-6-7-imagery-user-guide.pdf)
- [Request Form(2017)](https://www.intelligence-airbusds.com/files/pmedia/public/r44226_9_airbus_data_request_form_may_2017.pdf)
- [Pleiades Neo](https://docs.up42.com/getting-started/data-products/pleiades-neo/)

### Maxar (ex Digital Globe)
- [Worldviews](https://earth.esa.int/eogateway/catalog/worldview-esa-archive)
- [System-Ready Imagery](https://resources.maxar.com/optical-imagery/system-ready-imagery-data-sheet)
- [View-Ready Imagery](https://resources.maxar.com/optical-imagery/view-ready-imagery-data-sheet)
- [Map-Ready Imagery](https://resources.maxar.com/optical-imagery/map-ready-imagery-data-sheet)
- [ISD](https://dg-cms-uploads-production.s3.amazonaws.com/uploads/document/file/106/ISD_External.pdf)
- [Digital Globe Standard Imagery (old)](https://earth.esa.int/eogateway/documents/20142/37627/DigitalGlobe-Standard-Imagery.pdf)
- [Digital Globe Products Guide (old)](https://www.geosoluciones.cl/documentos/worldview/DigitalGlobe-Core-Imagery-Products-Guide.pdf)
- [Conversion from DN to TOA reflectance](https://apollomapping.com/image_downloads/Maxar_AbsRadCalDataSheet2018v0.pdf)

### SuperView-1
- [Imagery Product Guide](http://en.spacewillinfo.com/uploads/soft/210106/8-210106153503.pdf)

### Instruments

Most instruments can be found on [OSCAR](https://space-test.oscar.wmo.int/oscar-test/instruments) or on [ESA Earth Online](https://earth.esa.int/eogateway/en/missions).

### Band mapping

- You can find a magnificent band comparison chart on the [Imagico](http://blog.imagico.de/satellite-comparison-update/)
  blog.
- [L8-S2](https://reader.elsevier.com/reader/sd/pii/S0034425718301883)
- [All Landsats](https://landsat.gsfc.nasa.gov/wp-content/uploads/2016/10/all_Landsat_bands.png)
- [S2](https://discovery.creodias.eu/dataset/72181b08-a577-4d55-8ece-d8485167beb7/resource/d8f5dd92-b35c-46ee-98a2-0879dad03fce/download/res_band_s2_1.png)
- [S3 OLCI](https://discovery.creodias.eu/dataset/a0960a9b-c9c4-46db-bca5-ec79d0dda32b/resource/de8300a4-08cd-41aa-96ec-d9813115cc08/download/s3_res_band_ol.png)
- [S3 SLSTR](https://discovery.creodias.eu/dataset/ea8f247e-d193-4368-8cf6-8687a03a5306/resource/8e5c485a-d832-42be-ad9c-af500b468f29/download/s3_slcs.png)
- [S2 and PlanetScope](https://developers.planet.com/docs/apis/data/sensors/#the-psbsd-instrument)

### Index

- [Index consistency](https://www.indexdatabase.de/)
- [WorldView Index](https://resources.maxar.com/optical-imagery/multispectral-reference-guide)
- Specific sources inside the index function documentation in {meth}`~eoreader.bands.indices`
